# API

```{eval-rst}

.. currentmodule:: nuance

.. autosummary::
   :toctree: generated
   :nosignatures:
   :template: class.rst

   Star

```

```{eval-rst}

.. currentmodule:: nuance

.. automodule:: nuance.linear_search
   :members:
   :show-inheritance:


.. automodule:: nuance.periodic_search
   :members:
   :show-inheritance:


.. automodule:: nuance.core
   :members:
   :show-inheritance:

```